.g-job-info-key{font-weight:700;margin:12px 8px 0 0;font-size:16px}.g-job-info-key.inline,.g-job-info-value.inline{display:inline-block}.g-job-status-badge{border-radius:2px;font-weight:700;display:inline;padding:4px 9px 4px 4px;text-transform:uppercase;font-size:13px}.g-job-cancel{margin-left:10px;padding:2px 8px}.g-job-timeline-container{margin-top:5px}.check-menu-dropdown{position:relative;width:20px;left:-2px}.check-menu-dropdown .g-job-check-menu-button{padding:2px 1px 0 2px}.check-menu-dropdown .g-job-check-menu-button i{position:relative;top:-3px}.g-jobs-list-table{width:100%}.g-jobs-list-table th{border-bottom:1px solid #d7d7d7}.g-jobs-list-table tbody>tr{-webkit-transition:background .4s linear;-moz-transition:background .4s linear;-o-transition:background .4s linear;-ms-transition:background .4s linear;transition:background .4s linear}.g-jobs-list-table tbody>tr td{padding:3px 0}.g-jobs-list-table tbody>tr:hover{background-color:#f6f6f6}.g-jobs-list-table tbody>tr.g-highlight{background-color:#f1db74}.g-job-list-header{padding-bottom:10px}#g-job-checkbox-menu{display:inline}a.g-job-checkbox-menu-link{display:inline-block;overflow:hidden;-o-text-overflow:ellipsis;text-overflow:ellipsis;white-space:nowrap;color:#333}.g-job-filter-container{margin-top:7px}.g-job-filter-container>div{float:left;margin-right:10px}.g-job-filter-container>.checkbox{margin:0 0 0 10px}.g-job-filter-container .dropdown .dropdown-menu ul{list-style-type:none;padding:0;margin:0}.g-job-filter-container .dropdown .checkbox{margin:8px}.g-job-filter-container .dropdown .checkbox.g-job-checkall{padding-bottom:8px;border-bottom:1px solid #ddd}.g-page-size-container{float:right;margin-top:7px}.g-page-size-container>span{margin-right:10px}ul.g-jobs{margin:10px 0}.g-jobs-graph{height:calc(100vh - 230px);overflow-y:hidden;overflow-x:auto}.g-no-job-record{text-align:center}.g-job-worker-task-info{margin-top:10px}
